@@ -85,10 +85,17 @@ MediaContext::~MediaContext()
     {
         if (curAttribute.scalabilityState)
         {
-            curAttribute.scalabilityState->Destroy();
+            MOS_STATUS status = curAttribute.scalabilityState->Destroy();
+            if (MOS_FAILED(status))
+            {
+                MOS_OS_ASSERTMESSAGE("scalabilityState destroy fail.");
+            }
             MOS_Delete(curAttribute.scalabilityState);
             // set legacy MOS ve interface to null to be compatible to legacy MOS
-            m_osInterface->pVEInterf = nullptr;
+            if (m_osInterface)
+            {
+                m_osInterface->pVEInterf = nullptr;
+            }
         }
         else
         {
@@ -246,7 +253,7 @@ MOS_STATUS MediaContext::SearchContext(MediaFunction func, T params, uint32_t& i
                 MOS_OS_CHK_STATUS_RETURN(m_osInterface->pfnSetGpuContextHandle(m_osInterface, curAttribute.gpuContext, curAttribute.ctxForLegacyMos));
                 // set legacy MOS ve interface to current reused scalability state's ve interface
                 m_osInterface->pVEInterf = curAttribute.scalabilityState->m_veInterface;
-                if (m_osInterface->apoMosEnabled)
+                if (m_osInterface->apoMosEnabled || m_osInterface->apoMosForLegacyRuntime)
                 {
                     if (curAttribute.scalabilityState->m_veState)
                     {
